@@ -1,6 +1,10 @@
 package Log::Shiras::Report;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.44.0");
+use version; our $VERSION = version->declare("v0.46.0");
+use strict;
+use warnings;
+use 5.010;
+use utf8;
 #~ use lib '../../';
 #~ use Log::Shiras::Unhide qw( :InternalReporT );
 ###InternalReporT	warn "You uncovered internal logging statements for Log::Shiras::Report-$VERSION" if !$ENV{hide_warn};
