@@ -1,6 +1,8 @@
 package Log::Shiras::Report::Test2Note;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.44.0");
+use version; our $VERSION = version->declare("v0.46.0");
+use strict;
+use warnings;
 use 5.010;
 use utf8;
 use Moose;
@@ -43,7 +45,6 @@ sub add_line{
 	use warnings 'uninitialized';
 }
 
-
 #########1 Phinish    	      3#########4#########5#########6#########7#########8#########9
 
 __PACKAGE__->meta->make_immutable;
