@@ -1,18 +1,19 @@
 package Log::Shiras::Telephone;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.44.0");
-#~ use lib '../../';
-#~ use Log::Shiras::Unhide qw( :InternalTelephonE );
-###InternalTelephonE	warn "You uncovered internal logging statements for Log::Shiras::Telephone-$VERSION" if !@$ENV{hide_warn};
+use version; our $VERSION = version->declare("v0.46.0");
+use strict;
+use warnings;
 use 5.010;
 use utf8;
+use lib '../../';
+#~ use Log::Shiras::Unhide qw( :InternalTelephonE );
+###InternalTelephonE	warn "You uncovered internal logging statements for Log::Shiras::Telephone-$VERSION" if !@$ENV{hide_warn};
 use Moose;
 use	MooseX::StrictConstructor;
 use	MooseX::HasDefaults::RO;
 use MooseX::Types::Moose qw( Bool ArrayRef HashRef Str );
 use Carp qw( longmess );
 use Clone 'clone';
-use lib '../../../lib',;
 use Log::Shiras::Switchboard;
 my	$switchboard = Log::Shiras::Switchboard->instance;
 use Log::Shiras::Types qw( NameSpace ElevenInt );
